==> spring_98.0+dfsg.orig.tar.xz: spring-98.0/cont/LuaUI/callins.lua <==
--------------------------------------------------------------------------------
--------------------------------------------------------------------------------
--
--  file:    callins.lua
--  brief:   array and map of call-ins
--  author:  Dave Rodgers
--
--  Copyright (C) 2007.
--  Licensed under the terms of the GNU GPL, v2 or later.
--
--------------------------------------------------------------------------------
--------------------------------------------------------------------------------

CallInsList = {

  "Shutdown",
  "LayoutButtons",
  "ConfigureLayout",
  "CommandNotify",

  "KeyPress",
  "KeyRelease",
  "MouseMove",
  "MousePress",
  "MouseRelease",
  "JoyAxis",
  "JoyHat",
  "JoyButtonDown",
  "JoyButtonUp",
  "IsAbove",
  "GetTooltip",
  "AddConsoleLine",
  "GroupChanged",
  "WorldTooltip",

  "GameLoadLua",
  "GameStartPlaying",
  "GameOver",
  "TeamDied",

  "UnitCreated",
  "UnitFinished",
  "UnitFromFactory",
  "UnitDestroyed",
  "UnitTaken",
  "UnitGiven",
  "UnitIdle",
  "UnitCommand",
  "UnitSeismicPing",
  "UnitEnteredRadar",
  "UnitEnteredLos",
  "UnitLeftRadar",
  "UnitLeftLos",
  "UnitLoaded",
  "UnitUnloaded",

  "UnitEnteredWater",
  "UnitEnteredAir",
  "UnitLeftWater",
  "UnitLeftAir",

  "FeatureCreated",
  "FeatureDestroyed",

  "DrawGenesis",
  "DrawWorld",
  "DrawWorldPreUnit",
  "DrawWorldShadow",
  "DrawWorldReflection",
  "DrawWorldRefraction",
  "DrawScreenEffects",
  "DrawScreen",
  "DrawInMiniMap",

  "Explosion",
  "ShockFront",

  "RecvSkirmishAIMessage",

  "GameFrame",
  "CobCallback",
  "AllowCommand",
  "CommandFallback",
  "AllowUnitCreation",
  "AllowUnitTransfer",
  "AllowUnitBuildStep",
  "AllowFeatureCreation",
  "AllowFeatureBuildStep",
  "AllowResourceLevel",
  "AllowResourceTransfer",

  "GameProgress",
}


-- make the map
CallInsMap = {}
for _, callin in ipairs(CallInsList) do
  CallInsMap[callin] = true
end


--------------------------------------------------------------------------------
--------------------------------------------------------------------------------

==> spring_101.0+dfsg.orig.tar.xz: spring-101.0/cont/LuaUI/callins.lua <==
--------------------------------------------------------------------------------
--------------------------------------------------------------------------------
--
--  file:    callins.lua
--  brief:   array and map of call-ins
--  author:  Dave Rodgers
--
--  Copyright (C) 2007.
--  Licensed under the terms of the GNU GPL, v2 or later.
--
--------------------------------------------------------------------------------
--------------------------------------------------------------------------------

CallInsList = {

  "Shutdown",
  "LayoutButtons",
  "ConfigureLayout",
  "CommandNotify",

  "KeyPress",
  "KeyRelease",
  "TextInput",
  "MouseMove",
  "MousePress",
  "MouseRelease",
  "JoyAxis",
  "JoyHat",
  "JoyButtonDown",
  "JoyButtonUp",
  "IsAbove",
  "GetTooltip",
  "AddConsoleLine",
  "GroupChanged",
  "WorldTooltip",

  "GameLoadLua",
  "GameStartPlaying",
  "GameOver",
  "TeamDied",

  "UnitCreated",
  "UnitFinished",
  "UnitFromFactory",
  "UnitDestroyed",
  "RenderUnitDestroyed",
  "UnitTaken",
  "UnitGiven",
  "UnitIdle",
  "UnitCommand",
  "UnitSeismicPing",
  "UnitEnteredRadar",
  "UnitEnteredLos",
  "UnitLeftRadar",
  "UnitLeftLos",
  "UnitLoaded",
  "UnitUnloaded",

  "UnitEnteredWater",
  "UnitEnteredAir",
  "UnitLeftWater",
  "UnitLeftAir",

  "FeatureCreated",
  "FeatureDestroyed",

  "DrawGenesis",
  "DrawWorld",
  "DrawWorldPreUnit",
  "DrawWorldShadow",
  "DrawWorldReflection",
  "DrawWorldRefraction",
  "DrawScreenEffects",
  "DrawScreen",
  "DrawInMiniMap",

  "Explosion",
  "ShockFront",

  "RecvSkirmishAIMessage",

  "GameFrame",
  "CobCallback",
  "AllowCommand",
  "CommandFallback",
  "AllowUnitCreation",
  "AllowUnitTransfer",
  "AllowUnitBuildStep",
  "AllowFeatureCreation",
  "AllowFeatureBuildStep",
  "AllowResourceLevel",
  "AllowResourceTransfer",

  "GameProgress",

  "DownloadQueued",
  "DownloadStarted",
  "DownloadFinished",
  "DownloadFailed",
  "DownloadProgress",
}


-- make the map
CallInsMap = {}
for _, callin in ipairs(CallInsList) do
  CallInsMap[callin] = true
end


--------------------------------------------------------------------------------
--------------------------------------------------------------------------------
